@@ -23,23 +23,23 @@ OTHER DEALINGS IN THE SOFTWARE.
 
 #if defined(_WIN64 ) || defined(__x86_64__) || defined(__LP64__)
     #define GMM_ENTRY_NAME      "OpenGmm"
-    #define GMM_INIT_NAME       "GmmInit"
+    #define GMM_INIT_NAME       "InitializeGmm"
     #define GMM_DESTROY_NAME    "GmmDestroy"
 
     #if defined(_WIN64)
         #define GMM_UMD_DLL     "igdgmm64.dll"
     #else
-        #define GMM_UMD_DLL     "libigdgmm.so.11"
+        #define GMM_UMD_DLL     "libigdgmm.so.12"
     #endif
 #else
     #define GMM_ENTRY_NAME      "_OpenGmm@4"
 
-    #define GMM_INIT_NAME       "_GmmInit@48"
+    #define GMM_INIT_NAME       "_InitializeGmm@8"
     #define GMM_DESTROY_NAME    "_GmmDestroy@4"
 
     #if defined(_WIN32)
         #define GMM_UMD_DLL     "igdgmm32.dll"
     #else
-        #define GMM_UMD_DLL     "libigdgmm.so.11"
+        #define GMM_UMD_DLL     "libigdgmm.so.12"
     #endif
 #endif
